# pyregrws

[![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/jsenecal/pyregrws/ci.yml?label=CI&style=for-the-badge)](https://github.com/jsenecal/pyregrws/actions/workflows/ci.yml)[![PyPI](https://img.shields.io/pypi/v/pyregrws?style=for-the-badge)](https://pypi.org/project/pyregrws/)[![Codecov](https://img.shields.io/codecov/c/github/jsenecal/pyregrws?style=for-the-badge)](https://codecov.io/github/jsenecal/pyregrws)

## Currently Supported Payloads

- [POC](https://www.arin.net/resources/manage/regrws/payloads/#poc-payload)
- [Customer](https://www.arin.net/resources/manage/regrws/payloads/#customer-payload)
- [ORG](https://www.arin.net/resources/manage/regrws/payloads/#org-payload)
- [NET Block](https://www.arin.net/resources/manage/regrws/payloads/#net-block-payload)
- [NET](https://www.arin.net/resources/manage/regrws/payloads/#net-payload)
- [POC Link](https://www.arin.net/resources/manage/regrws/payloads/#poc-link-payload)

- [Ticketed Request Payload](https://www.arin.net/resources/manage/regrws/payloads/#ticketed-request-payload)
- [Ticket Payload](https://www.arin.net/resources/manage/regrws/payloads/#ticket-payload)

- [Error](https://www.arin.net/resources/manage/regrws/payloads/#error-payload)
